﻿Type=Class
Version=4.2
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
'Class module
Sub Class_Globals
	Private ws As WebSocket 'ignore
	' will hold our page information
	Public page As ABMPage
	' page theme
	Private theme As ABMTheme
	' to access the constants
	Private ABM As ABMaterial 'ignore	
	' name of the page, must be the same as the class name (case sensitive!)
	Public Name As String = "CompDividerPage"
	' name of the app, same as in ABMApplication
	Public AppName As String = "demo"
	
	' your own variables
	Dim myToastId As Int
End Sub

'Initializes the object. You can add parameters to this method if needed.
Public Sub Initialize
	' build the local structure IMPORTANT!
	BuildPage
End Sub

Private Sub WebSocket_Connected (WebSocket1 As WebSocket)
	Log("Connected")
	ws = WebSocket1	
	If ABMShared.NeedsAuthorization Then
		If ws.Session.GetAttribute2("IsAuthorized", "") = "" Then
			ABMShared.NavigateToPage(ws, "../")
			Return
		End If
	End If
	' connect our page with the websocket	
	page.SetWebSocket(ws)
	' Prepare the page IMPORTANT!
	page.Prepare	
End Sub

Private Sub WebSocket_Disconnected
	Log("Disconnected")
End Sub

Sub Page_ParseEvent(Params As Map) 
	Dim eventName As String = Params.Get("eventname")
	Dim eventParams() As String = Regex.Split(",",Params.Get("eventparams"))
	If SubExists(Me, eventName) Then
		Params.Remove("eventname")
		Params.Remove("eventparams")
		Select Case Params.Size
			Case 0
				CallSub(Me, eventName)
			Case 1
				CallSub2(Me, eventName, Params.Get(eventParams(0)))					
			Case 2
				If Params.get(eventParams(0)) = "abmistable" Then
					Dim PassedTables As List = ABM.ProcessTablesFromTargetName(Params.get(eventParams(1)))
					CallSub2(Me, eventName, PassedTables)
				Else
					CallSub3(Me, eventName, Params.Get(eventParams(0)), Params.Get(eventParams(1)))
				End If
			Case Else
				' cannot be called diretly, to many param
				CallSub2(Me, eventName, Params)				
		End Select
	End If
End Sub

public Sub BuildTheme()
	' start with the base theme defined in ABMShared
	theme.Initialize("pagetheme")
	theme.AddABMTheme(ABMShared.MyTheme)
	
	' add additional themes specific for this page
	theme.AddDividerTheme("lightblue")
	theme.Divider("lightblue").ForeColor = ABM.COLOR_LIGHTBLUE
End Sub

public Sub BuildPage()
	' initialize the theme
	BuildTheme
	
	' initialize this page using our theme
	page.InitializeWithTheme(Name, "/ws/" & AppName & "/" & Name, False, theme)
	page.ShowLoader=True
	page.PageTitle = "ABMDivider"
	page.PageDescription = "The divider component "	
	page.PageHTMLName = "abmaterial-divider.html"
	page.PageKeywords = "ABMaterial, material design, B4X, B4J, SEO, framework, search engine optimization"
	page.PageSiteMapPriority = "0.50"
	page.PageSiteMapFrequency = ABM.SITEMAP_FREQ_MONTHLY
	page.UseGoogleAnalytics(ABMShared.TrackingID, Null) ' IMPORTANT Change this to your own TrackingID !!!!!!!
		
	ABMShared.BuildNavigationBar(page, "ABMDivider", "../images/logo.png", "", "Controls", "ABMdivider")
		
	' create the page grid
	page.AddRows(4,True, "").AddCells12(1,"")
	page.AddRows(1,True, "").AddCellsOS(2,0,0,0,6,6,6,"")
	page.AddRows(1,True, "").AddCells12(1,"")
	page.BuildGrid 'IMPORTANT once you loaded the complete grid AND before you start adding components
	
	' add paragraph	
	page.Cell(1,1).AddComponent(ABMShared.BuildParagraph(page,"par1","You can use an ABMDivider to break up your content.  Dividers are 1 pixel lines.") )	
	' add paragraph
	page.Cell(1,1).AddComponent(ABMShared.BuildParagraph(page,"par2","You can add one to a row with the SetDivider() method. Note: a divider set on a row will always be at the {B}top{/B} of the row!  You've may want to add an extra row if you want to make it appear like the divider is under your last section."))
	
	' add a divider on the row
	Dim div1 As ABMDivider
	div1.Initialize(page, "div1", "lightblue")
	page.Row(2).SetDivider(div1)
	
	' code block
	Dim code1 As String = $"// add a divider on the row
Dim div1 As ABMDivider
div1.Initialize(page, "div1", "lightblue")
page.Row(2).SetDivider(div1)"$
	
	page.Cell(3,1).AddComponent(ABMShared.BuildCodeBlockFromSmartString(page, "code1", code1))
	
	' add paragraph
	page.Cell(4,1).AddComponent(ABMShared.BuildParagraph(page,"par2","Dividers can also be set on cell level as a normal component using the AddComponent() method."))
	
	' add a loop of a divider and a label
	For i = 2 To 4
		Dim div2 As ABMDivider
		div2.Initialize(page, "div" & i, "lightblue")
		page.Cell(5,1).AddComponent(div2)
		Dim lbl2 As ABMLabel
		lbl2.Initialize(page, "lbl" & i, "Some text...", ABM.SIZE_H6, True, "")
		page.Cell(5,1).AddComponent(lbl2)
	Next
	' add one at hte end of the cell
	Dim divend As ABMDivider
	divend.Initialize(page, "divend", "lightblue")
	page.Cell(5,1).AddComponent(divend)
	
	' code block
	Dim code2 As String = $"// add a loop of a divider and a label
For i = 2 To 4
	Dim div2 As ABMDivider
	div2.Initialize(page, "div" & i, "lightblue")
	page.Cell(5,1).AddComponent(div2)
	Dim lbl2 As ABMLabel
	lbl2.Initialize(page, "lbl" & i, "Some text...", ABM.SIZE_H6, True, "")
	page.Cell(5,1).AddComponent(lbl2)
Next
// add one at the end of the cell
Dim divend As ABMDivider
divend.Initialize(page, "divend", "lightblue")
page.Cell(5,1).AddComponent(divend)"$
	
	page.Cell(6,1).AddComponent(ABMShared.BuildCodeBlockFromSmartString(page, "code2", code2))
	
	ABMShared.BuildFooter(page)
End Sub

' clicked on the navigation bar
Sub Page_NavigationbarClicked(Action As String, Value As String)
	page.SaveNavigationBarPosition	
	If Action = "ABMDivider" Then Return
	If Action = "Contact" Then	
		myToastId = myToastId + 1	
		page.ShowToast("toast" & myToastId, "toastred", "Hello to you too!", 5000)
		Return
	End If
	If Action = "LogOff" Then
		ABMShared.LogOff(page)
		Return
	End If
	ABMShared.NavigateToPage(ws, Value)
End Sub

Sub Page_SignedOffSocialNetwork(Network As String, Extra As String)
	page.ws.Session.SetAttribute("authType", "")
	page.ws.Session.SetAttribute("authName", "")
	page.ws.Session.SetAttribute("IsAuthorized", "")			
	ABMShared.NavigateToPage(page.ws, "../")
End Sub

Sub Page_Ready()
	Log("ready!")
	page.RestoreNavigationBarPosition
End Sub